echo Script file for generating XML Schema documentation
echo using xs3p schema documentation generator.
echo ""
echo Usage: sh schemaDocumentation.sh -xsdPath=\"path/To/XSD/File\" -imageFolder=\"path/To/Images/Folder\" -mainOutputDir=\"main/Output/Dir/\" -htmlFileName=\"fileName.html\" -diagramExtension=\".jpg\" -useHashCodes=\"true\" -generateChunks=\"false\" -hideComments=\"true\" -hideAnnotations=\"true\" -cssURL=\"file://path/To/CSS\"
echo ----------------------------------------------------------------------------------------------
echo Parameters:
echo -xsdPath  - The path to XML Schema file
echo -imageFolder  - The path to the folder where generated images will be saved into. Relative 
echo                     to the mainOutputDir
echo -mainOutputDir - The path to the html output directory. This contains the HTML files and the images directory. Must be ended in /
echo -htmlFileName - The name of the HTML file relative to mainOutputDir.
echo -diagramExtension - Optional \(defaults to .png\). Either ".png" or ".jpg" to specify the diagrams type
echo -useHashCodes - Optional \(defaults to true\). If enabled then the achors and links will be generated using the hashcode of the component
echo      identifier instead of using the identifier itself. This is useful when the schema componet
echo      names contain characters that are not directly supported by the browsers or by the file system.
echo      Possible values are true/false. 
echo -generateChunks - Optional \(defaults to false\). For large schemas you can use 'Generate chunks' option
echo      Possible values are true/false. 
echo -hideComments - Optional \(defaults to true\). Hides/ Shows comments present in the generated diagram images.
echo      Possible values are true/false. 
echo -hideAnnotations - Optional \(defaults to true\). Hides/ Shows annotations present in the generated diagram images.
echo      Possible values are true/false. 
echo -cssURL - Optional. The URL of the stylesheet to be used by the generated HTML files. Must be specified in URL syntax.
echo Example: sh schemaDocumentation.sh -xsdPath=\"samples/personal.xsd\" -imageFolder=\"schemaDiagrams\" -mainOutputDir=\"samples\" -htmlFileName=\"personal.xsd.html\" -diagramExtension=\".png\" -useHashCodes=\"true\" -generateChunks=\"false\" -cssURL=\"personal.css\" -hideComments=\"true\" -hideAnnotations=\"true\"
echo ----------------------------------------------------------------------------------------------

case "$0" in
/*)
  p=$0
;;
*) p=`/bin/pwd`/$0
;;
esac
p=`dirname "$p"`

#Default values for optional parameters.
GENERATE_CHUNKS=false
USE_HASH_CODES=true
HIDE_COMMENTS=true
HIDE_ANNOTATIONS=true
DIAGRAMS_EXTENSION=.png

until [ -z "$1" ]
    do
      tmp=${1:1}               # Strip off leading '-' . . .
      parameter=${tmp%%=*}     # Extract name.
      value=${tmp##*=}         # Extract value.
      if [ "$parameter" == "xsdPath" ]; then 
       XSD_PATH="$value"
      fi
      if [ "$parameter" == "imageFolder" ]; then 
       IMAGES_FOLDER="$value"
      fi
      if [ "$parameter" == "mainOutputDir" ]; then 
       MAIN_OUTPUT_DIR="$value"
      fi
      if [ "$parameter" == "htmlFileName" ]; then 
       HTML_FILE_NAME="$value"
      fi
      if [ "$parameter" == "diagramExtension" ]; then 
       DIAGRAMS_EXTENSION="$value"
      fi
      if [ "$parameter" == "useHashCodes" ]; then 
       USE_HASH_CODES="$value"
      fi
      if [ "$parameter" == "generateChunks" ]; then 
       GENERATE_CHUNKS="$value"
      fi
      if [ "$parameter" == "hideComments" ]; then 
       HIDE_COMMENTS="$value"
      fi
      if [ "$parameter" == "hideAnnotations" ]; then 
       HIDE_ANNOTATIONS="$value"
      fi
      if [ "$parameter" == "cssURL" ]; then 
        CSS_URL="$value"
      fi
      shift
done

if [ "$XSD_PATH" != "" -a "$IMAGES_FOLDER" != "" -a "$MAIN_OUTPUT_DIR" != "" -a "$HTML_FILE_NAME" != "" ]; then
  CP=$p:$p/classes:$p/lib/oxygen.jar:$p/lib/xml-apis.jar:$p/lib/xercesImpl.jar:$p/lib/log4j.jar:$p/lib/resolver.jar:$p/lib/jimi.zip


  # generates diagrams
  java -cp "$CP" ro.sync.exml.SwingSDImageGenerator -xsdPath "$XSD_PATH" -imageFolder "$MAIN_OUTPUT_DIR/$IMAGES_FOLDER" -diagramExtension "$DIAGRAMS_EXTENSION" -useHashCodes "$USE_HASH_CODES" -generateChunks "$GENERATE_CHUNKS" -hideComments "$HIDE_COMMENTS" -hideAnnotations "$HIDE_ANNOTATIONS" -htmlFileName "$HTML_FILE_NAME"
 
  RETCODE=$?
  if [ "$RETCODE" -ne "0" ]; then
  echo "Images generation did not succeed, return code "$RETCODE
  exit 1
  fi

#generate the documentation file
echo Starting stylesheet processor

if [ "$CSS_URL" != "" ]; then
java -cp "$p/lib/saxon8.jar" net.sf.saxon.Transform -o "$MAIN_OUTPUT_DIR/$HTML_FILE_NAME" "$XSD_PATH"  "$p/frameworks/xs3p/xs3p.xsl"\
 showDiagrams=true\
 imagesBaseURL="$IMAGES_FOLDER"\
 sortByComponent=true\
 useJavaScript=true\
 printAllSuperTypes=true\
 printAllSubTypes=true\
 printLegend=true\
 printGlossary=true\
 printNSPrefixes=true\
 mainSchemaOutputFile="$HTML_FILE_NAME"\
 showLogicalDiagrams=true\
 mainDocBase="$MAIN_OUTPUT_DIR"\
 mainDocFile="$HTML_FILE_NAME"\
 diagramImagesExtension=$DIAGRAMS_EXTENSION\
 useHashcodes=$USE_HASH_CODES\
 generateChunks=$GENERATE_CHUNKS\
 externalCSSURL="$CSS_URL"
 else
java -cp "$p/lib/saxon8.jar" net.sf.saxon.Transform -o "$MAIN_OUTPUT_DIR/$HTML_FILE_NAME" "$XSD_PATH"  "$p/frameworks/xs3p/xs3p.xsl"\
 showDiagrams=true\
 imagesBaseURL="$IMAGES_FOLDER"\
 sortByComponent=true\
 useJavaScript=true\
 printAllSuperTypes=true\
 printAllSubTypes=true\
 printLegend=true\
 printGlossary=true\
 printNSPrefixes=true\
 mainSchemaOutputFile="$HTML_FILE_NAME"\
 showLogicalDiagrams=true\
 mainDocBase="$MAIN_OUTPUT_DIR"\
 mainDocFile="$HTML_FILE_NAME"\
 diagramImagesExtension=$DIAGRAMS_EXTENSION\
 useHashcodes=$USE_HASH_CODES\
 generateChunks=$GENERATE_CHUNKS
fi

echo Finished

else 
  ERROR_MESSAGE="The following parameters are not specified:"
  if [ "$XSD_PATH" == "" ]; then
    ERROR_MESSAGE=$ERROR_MESSAGE" xsdPath,"
  fi
  if [ "$IMAGES_FOLDER" == "" ]; then
    ERROR_MESSAGE=$ERROR_MESSAGE" imageFolder,"
  fi
  if [ "$MAIN_OUTPUT_DIR" == "" ]; then
    ERROR_MESSAGE=$ERROR_MESSAGE" mainOutputDir,"
  fi
  if [ "$HTML_FILE_NAME" == "" ]; then
    ERROR_MESSAGE=$ERROR_MESSAGE" htmlFileName,"
  fi
  ERROR_MESSAGE=$ERROR_MESSAGE". Correct command line arguments and try again."
  echo $ERROR_MESSAGE
fi
